
class AppSettings(object):
    '''Thanks django-allauth'''
    __SENTINEL = object()

    def __init__(self, prefix):
        self.prefix = prefix

    def _setting(self, name, dflt=__SENTINEL):
        from django.conf import settings
        from django.core.exceptions import ImproperlyConfigured

        v  = getattr(settings, self.prefix + name, dflt)
        if v is self.__SENTINEL:
            raise ImproperlyConfigured('Missing setting %r' % (self.prefix + name))
        return v

    @property
    def enabled(self):
        return self._setting('ENABLED', False)

    @property
    def create(self):
        return self._setting('CREATE', True)

    @property
    def authorize_url(self):
        return self._setting('AUTHORIZE_URL', 'https://fcp.integ01.dev-franceconnect.fr/api/v1/authorize')

    @property
    def token_url(self):
        return self._setting('TOKEN_URL', 'https://fcp.integ01.dev-franceconnect.fr/api/v1/token')

    @property
    def userinfo_url(self):
        return self._setting('USERINFO_URL', 'https://fcp.integ01.dev-franceconnect.fr/api/v1/userinfo')

    @property
    def logout_url(self):
        return self._setting('LOGOUT_URL', 'https://fcp.integ01.dev-franceconnect.fr/api/v1/logout')

    @property
    def client_id(self):
        return self._setting('CLIENT_ID')

    @property
    def client_secret(self):
        return self._setting('CLIENT_SECRET')

    @property
    def verify_certificate(self):
        return self._setting('VERIFY_CERTIFICATE', False)

    @property
    def client_credentials(self):
        return self._setting('CLIENT_CREDENTIALS', ())

import sys

app_settings = AppSettings('A2_FC_')
app_settings.__name__ = __name__
sys.modules[__name__] = app_settings
