import requests
import json
import logging
import urlparse

from requests_oauthlib import OAuth2Session

from authentic2.compat import user_model_label
from django.db import models
from django.db.models.query import Q
from django.db.models.signals import post_save
from django.utils.translation import ugettext_lazy as _
from django.dispatch import receiver
from django.conf import settings

from . import app_settings

class FcAccount(models.Model):
    user = models.ForeignKey(
            to=settings.AUTH_USER_MODEL,
            verbose_name=_('user'),
            default=None,
            null=True)
    sub = models.TextField(verbose_name=_('sub'))
    token = models.TextField(verbose_name=_('access token'))

    def refresh_token(self):
        logger = logging.getLogger(__name__)

        if not self.token:
            return True
        token = json.loads(self.token)
        data = {
                'grant_type': 'refresh_token',
                'refresh_token': token['refresh_token'],
                'client_id': app_settings.client_id,
                'client_secret': app_settings.client_secret,
        }
        response = requests.post(app_settings.token_url,
                data=data, verify=app_settings.verify_certificate)

        new_token = response.json()
        if 'error' in new_token:
            if new_token['error'] == 'invalid_grant':
                logger.warning('obsolete token %r, deleting FcAccount %r', self.token,
                        self.sub)
                self.delete()
                return False
            return True
        else:
            self.token = json.dumps(new_token)
            self.save()
            return True
